@@ -32,6 +32,7 @@ OC.L10N.register(
     "Privacy" : "الخصوصية",
     "Add a bookmark" : "إضافة فاصلة مرجعية",
     "Title" : "العنوان",
-    "Link" : "الرابط"
+    "Link" : "الرابط",
+    "Folder" : "مجلد"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
