@@ -19,6 +19,7 @@ OC.L10N.register(
     "Allow editing" : "Dozvolite izmjenu",
     "Select" : "Select",
     "Title" : "Naslov",
-    "Link" : "Veza"
+    "Link" : "Veza",
+    "Folder" : "Fasikla"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
