@@ -23,6 +23,7 @@ OC.L10N.register(
     "Copy link" : "Copïo dolen",
     "Select" : "Select",
     "Title" : "Teitl",
-    "Link" : "Dolen"
+    "Link" : "Dolen",
+    "Folder" : "Plygell"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
