@@ -22,13 +22,17 @@ OC.L10N.register(
     "List view" : "Listasýn",
     "Move selection" : "Færa valið",
     "Delete selection" : "Eyða vali",
+    "Open all selected" : "Opna allt valið",
     "Select all visible" : "Velja allt sýnilegt",
     "Cancel selection" : "Hætta við val",
+    "Selected {folders} folders and {bookmarks} bookmarks" : "Valdar {folders} möppur og {bookmarks} bókamerki",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valdi %n bókamerki","Valdi %n bókamerki"],
+    "_Selected %n folder_::_Selected %n folders_" : ["Valin %n mappa","Valdar %n möppur"],
     "Enter a link" : "Settu inn slóð",
     "Create" : "Búa til",
     "Cancel" : "Hætta við",
     "Enter folder title" : "Settu inn heiti möppu",
+    "Select folder" : "Veldu möppu",
     "Shared by {user}" : "Deilt af {user}",
     "Shared privately" : "Deilt sem einkamáli",
     "Public" : "Opinbert",
@@ -70,12 +74,14 @@ OC.L10N.register(
     "Select a user or group" : "Veldu notanda eða hóp",
     "Share link" : "Deila tengli",
     "Copy link" : "Afrita tengil",
+    "Copy RSS feed" : "Afrita RSS-fréttastreymi",
     "Delete link" : "Eyða tengli",
     "Create public link" : "Búa til opinberan tengil",
     "Allow editing" : "Leyfa breytingar",
     "Allow sharing" : "Leyfa deilingu",
     "Remove share" : "Fjarlægja sameign",
     "Link copied" : "Tengill afritaður",
+    "RSS feed copied" : "RSS-fréttastreymi afritað",
     "Select" : "Velja",
     "Previews" : "Forskoðun",
     "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Til þess að birta raunverulegar skjámyndir af þeim vefsíðum sem þú bókamerkir, getur bókamerkjaforritið notað þjónustu utanaðkomandi aðila til að útbúa skjámyndirnar.",
@@ -97,6 +103,7 @@ OC.L10N.register(
     "Link" : "Tengill",
     "Enter bookmark URL" : "Settu inn slóð á bókamerki",
     "Folder" : "Mappa",
+    "Root Folder" : "Rótarmappa",
     "Failed to find existing bookmark" : "Mistókst að finna fyrirliggjandi bókamerki",
     "Failed to create bookmark" : "Mistókst að búa til bókamerki",
     "Failed to save bookmark" : "Mistókst að vista bókamerki",
