@@ -4,21 +4,37 @@ OC.L10N.register(
     "Bookmarks" : "북마크",
     "No file provided for import" : "가져올 파일을 지정하지 않았음",
     "Unsupported file type for import" : "지원하지 않는 가져오기 파일 형식",
+    "Bookmarks shared by %s" : "%s이(가) 공유한 북마크 ",
     "A Bookmark manager for Nextcloud" : "Nextcloud 북마크 관리자",
+    "Select bookmark" : "북마크 선택",
     "Details" : "자세한 정보",
     "Rename" : "이름 바꾸기",
     "Move" : "이동",
     "Delete" : "삭제",
+    "Enter bookmark title" : "북마크 제목을 입력하시오.",
     "Save" : "저장",
+    "New bookmark" : "새로운 북마크",
     "New folder" : "새 폴더",
     "Grid view" : "바둑판식 보기",
     "List view" : "목록 보기",
+    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["선택된 %n 북마크들"],
+    "_Selected %n folder_::_Selected %n folders_" : ["선택된 %n 폴더들"],
+    "Enter a link" : "링크를 입력하시오.",
     "Create" : "생성",
     "Cancel" : "취소",
+    "Enter folder title" : "폴더명을 입력하시오.",
+    "Select folder" : "폴더 선택",
+    "Shared by {user}" : "{user}가 공유한",
+    "Shared privately" : "사적으로 공유됨",
     "Public" : "공개",
     "Root folder" : "루트 폴더",
+    "New Bookmark" : "새로운 북마크",
+    "All Bookmarks" : "모든 북마크",
+    "Recent Bookmarks" : "최근 북마크",
+    "Untagged" : "태그 지우기",
     "Import" : "가져오기",
     "Export" : "내보내기",
+    "Sorting" : "정렬",
     "Recently added" : "최근에 추가됨",
     "Alphabetically" : "가나다순",
     "Most visited" : "가장 자주 방문함",
@@ -28,14 +44,17 @@ OC.L10N.register(
     "Permanently remove all bookmarks from your account. There is no going back!" : "계정에 있는 모든 북마크를 삭제합니다. 실행 취소할 수 없습니다!",
     "Delete all bookmarks" : "모든 북마크 삭제",
     "Bookmarklet" : "북마크릿",
+    "Add to {instanceName}" : "{instanceName}에 더하기",
     "Do you really want to delete all your bookmarks?" : "모든 북마크를 삭제하시겠습니까?",
     "URL" : "URL",
     "Tags" : "태그",
     "Notes" : "Notes",
     "Sharing" : "공유",
+    "{time} ago" : "{time} 전에",
     "Owner" : "Owner",
     "Share link" : "링크 공유",
     "Copy link" : "링크 복사",
+    "Delete link" : "링크 삭제",
     "Allow editing" : "Allow editing",
     "Link copied" : "링크 복사됨",
     "Select" : "선택",
@@ -44,11 +63,15 @@ OC.L10N.register(
     "Screeenly API URL" : "Screeenly API URL",
     "Screeenly API key" : "Screeenly API 키",
     "Privacy" : "프라이버시",
+    "Failed to load settings" : "환경설정 로딩 실패",
+    "Failed to save settings" : "환경설정 저장 실패",
     "Add a bookmark" : "북마크 추가",
     "This URL is already bookmarked! Overwrite?" : "이 URL이 북마크에 이미 추가되어 있습니다! 덮어쓰시겠습니까?",
     "Title" : "직위",
     "Link" : "링크",
+    "Enter bookmark URL" : "북마크 URL을 입력하시오.",
     "Folder" : "폴더",
+    "Root Folder" : "최상위 폴더",
     "Bookmarks feed" : "북마크 피드"
 },
 "nplurals=1; plural=0;");
