@@ -14,11 +14,13 @@ OC.L10N.register(
     "Save" : "Shrani",
     "No bookmarks here" : "Ni še dodanih zaznamkov.",
     "Select one or more tags" : "Izbor enega oziroma več zaznamkov",
+    "New bookmark" : "Nov zaznamek",
     "New folder" : "Nova mapa",
     "Grid view" : "Mrežni pogled",
     "List view" : "Seznamski pogled",
     "Move selection" : "Premakni izbor",
     "Delete selection" : "Izbriši izbor",
+    "Select all visible" : "Izberi vse vidno",
     "Enter a link" : "Vnesite povezavo",
     "Create" : "Ustvari",
     "Cancel" : "Prekliči",
@@ -55,7 +57,10 @@ OC.L10N.register(
     "Select a user or group" : "Izbor imena uporabnika oziroma skupine",
     "Share link" : "Povezava za souporabo",
     "Copy link" : "Kopiraj povezavo",
+    "Delete link" : "Izbriši povezavo",
+    "Create public link" : "Ustvari javno povezavo",
     "Allow editing" : "Dovoli urejanje",
+    "Allow sharing" : "Dovoli omogočanje souporabe",
     "Remove share" : "Odstrani souporabo",
     "Link copied" : "Povezava je kopirana",
     "Select" : "Izbor",
