@@ -10,7 +10,8 @@ use OCP\AppFramework\Db\Entity;
  * @package OCA\Bookmarks\Db
  *
  * @method getShareId
- * @method setShareId(int $shareId)
+ * @method setFolderId(int $shareId)
+ * @method getFolderId()
  * @method getUserId
  * @method setUserId(string $userId)
  * @method getTitle
@@ -20,19 +21,19 @@ class SharedFolder extends Entity {
 	protected $shareId;
 	protected $userId;
 	protected $title;
-	protected $index;
+	protected $folderId;
 
-	public static $columns = ['id', 'share_id', 'user_id', 'title'];
+	public static $columns = ['id', 'user_id', 'title', 'folder_id'];
 
 	public function __construct() {
 		// add types in constructor
 		$this->addType('id', 'integer');
-		$this->addType('shareId', 'integer');
 		$this->addType('userId', 'string');
+		$this->addType('folderId', 'integer');
 		$this->addType('title', 'string');
 	}
 
 	public function toArray() {
-		return ['title' => $this->title, 'userId' => $this->userId, 'shareId' => $this->shareId];
+		return ['title' => $this->title, 'userId' => $this->userId];
 	}
 }
